<?php
/*-------------------------------------------------------
 * @Module Name: LS Arduino
 * @Module URI: http://robocraft.ru
 * @Description: модуль получения данных от платы ардуино
 * @Version: 0.01
 * @Author: Vladimir (noonv)
 * @Author URI: http://robocraft.ru
 * @LiveStreet Version: 0.3.1
 * @License: RoboCraft.ru
 *----------------------------------------------------------------------------
 */

class Mapper_LsArduino extends Mapper
{
	//
	// Arduino
	// если не существует - создаём в БД таблицу для хранения сообщений
	//
	public function CreateTables()
	{
		$sql = "
		CREATE TABLE IF NOT EXISTS `".DB_TABLE_LSARDUINO."` (
		`note_id` int(11) unsigned NOT NULL auto_increment,
		`note_text` text default NULL,
		`note_data` text default NULL,
		`note_date` datetime default NULL,
		`note_user_id` int(11) unsigned NOT NULL,
		`note_visible` tinyint(1) unsigned NOT NULL default '1',
		PRIMARY KEY  (`note_id`)
		) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;
		";
		 $this->oDb->query($sql);
		// {
			// результат ненулевой - значит первый запуск - создаём и другие таблицы
			$sql ="
			CREATE TABLE IF NOT EXISTS `".DB_TABLE_LSARDUINO_ACTION_STATUS."` (
			`status_id` int(11) unsigned NOT NULL auto_increment,
			`status_name` varchar(100) default NULL,
			PRIMARY KEY  (`status_id`)
			) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;
			";
			
			$this->oDb->query($sql);

			$sql ="INSERT INTO `".DB_TABLE_LSARDUINO_ACTION_STATUS."` (`status_id`, `status_name`) VALUES
			('1', 'Новый'),
			('2', 'Загружен'),
			('3', 'Выполнен'),
			('4', 'Отклонён'),
			('5', 'Не выполнен'),
			('6', 'Отменён');
			";
			
			$this->oDb->query($sql);

			$sql ="CREATE TABLE IF NOT EXISTS `".DB_TABLE_LSARDUINO_ACTION."` (
			  `action_id` int(11) unsigned NOT NULL auto_increment,
			  `action_name` varchar(100) default NULL,
			  PRIMARY KEY  (`action_id`)
			) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;
			";

			$this->oDb->query($sql);
			
			$sql ="INSERT INTO `".DB_TABLE_LSARDUINO_ACTION."` (`action_id`, `action_name`) VALUES
			('1', 'LED on'),
			('2', 'LED off');
			";
			$this->oDb->query($sql);

			$sql ="CREATE TABLE IF NOT EXISTS `".DB_TABLE_LSARDUINO_TODO."` (
			  `todo_id` int(11) unsigned NOT NULL auto_increment,
			  `todo_user_id` int(11) unsigned NOT NULL,
			  `todo_action` int(11) unsigned NOT NULL,
			  `todo_text` text default NULL,
			  `todo_date` datetime default NULL,
			  `todo_status` int(11) unsigned NOT NULL,
			  PRIMARY KEY  (`todo_id`)
			) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1;
			";
			$this->oDb->query($sql);
		//}
	}

	//
	// Arduino
	// получаем последнее сообщение
	//
	public function GetLastNote()
	{
		$sql = "
			SELECT
				*
			FROM
				`".DB_TABLE_LSARDUINO."`
			ORDER BY `note_id` DESC
			LIMIT 1
		";
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows[0];
		}
	}

	//
	// Arduino
	// получаем все сообщения
	//
	public function GetAllNotes()
	{
		$sql = "
			SELECT
				".DB_TABLE_LSARDUINO.".*,".DB_TABLE_USER.".user_id,".DB_TABLE_USER.".user_login
			FROM
				`".DB_TABLE_LSARDUINO."`, `".DB_TABLE_USER."`
		WHERE ".DB_TABLE_USER.".user_id=".DB_TABLE_LSARDUINO.".note_user_id ORDER by ".DB_TABLE_LSARDUINO.".note_id";
		
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows;
		}
	}

	//
	// Arduino
	// новое сообщение
	//
	public function AddNote($note_text, $note_data, $note_date, $note_user_id, $note_visible)
	{
	
		$sql = "
			INSERT INTO
				`".DB_TABLE_LSARDUINO."`
			SET	
			  `note_text` = ?,
			  `note_data` = ?,
			  `note_date` = ?,
			  `note_user_id` = ?,
			  `note_visible` = ?
		";
		$this->oDb->query($sql, $note_text, $note_data, $note_date, $note_user_id, $note_visible);
	}

	//
	// Arduino
	// удаляем сообщение
	//
	public function DeleteNote($array)
	{
		foreach($array as $k=>$v)
		{
			$sql = "
				DELETE FROM
					`".DB_TABLE_LSARDUINO."`
				WHERE
					`note_id` = ?
			";
			$this->oDb->query($sql, $k);
		}
		return true;
	}
	
	//
	// Arduino
	// удаляем задание
	//
	public function DeleteAction($array)
	{
		foreach($array as $k=>$v)
		{
			$sql = "
				DELETE FROM
					`".DB_TABLE_LSARDUINO_TODO."`
				WHERE
					`todo_id` = ?
			";
			$this->oDb->query($sql, $k);
		}
		return true;
	}
	
	//
	// Arduino
	// получаем все задания
	//
	public function GetAllTodo()
	{
		$sql = "
			SELECT
				".DB_TABLE_LSARDUINO_TODO.".*,".DB_TABLE_USER.".user_id,".DB_TABLE_USER.".user_login
			FROM
				`".DB_TABLE_LSARDUINO_TODO."`, `".DB_TABLE_USER."`
		WHERE ".DB_TABLE_USER.".user_id=".DB_TABLE_LSARDUINO_TODO.".todo_user_id ORDER by ".DB_TABLE_LSARDUINO_TODO.".todo_id";
		
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows;
		}
	}
	
	//
	// Arduino
	// получаем только новые задания - статус 1
	//
	public function GetNewTodo()
	{
		$sql = "
			SELECT
				".DB_TABLE_LSARDUINO_TODO.".*,".DB_TABLE_USER.".user_id,".DB_TABLE_USER.".user_login
			FROM
				`".DB_TABLE_LSARDUINO_TODO."`, `".DB_TABLE_USER."`
		WHERE ".DB_TABLE_LSARDUINO_TODO.".todo_status ='1' AND ".DB_TABLE_USER.".user_id=".DB_TABLE_LSARDUINO_TODO.".todo_user_id ORDER by ".DB_TABLE_LSARDUINO_TODO.".todo_id";
		
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows;
		}
	}
	
	//
	// Arduino
	// получаем все статусы заданий
	//
	public function GetAllActionStatuses()
	{
		$sql = "
			SELECT
				*
			FROM
				`".DB_TABLE_LSARDUINO_ACTION_STATUS."`";
		
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows;
		}
	}
	
	//
	// Arduino
	// получаем все типы заданий
	//
	public function GetAllActions()
	{
		$sql = "
			SELECT
				*
			FROM
				`".DB_TABLE_LSARDUINO_ACTION."`";
		
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows;
		}
	}
	
	//
	// Arduino
	// новое задание
	//
	public function AddTodo($todo_user_id, $todo_action, $todo_text, $todo_date, $todo_status)
	{
		$sql = "
			INSERT INTO
				`".DB_TABLE_LSARDUINO_TODO."`
			SET	
			  `todo_user_id` = ?,
			  `todo_action` = ?,
			  `todo_text` = ?,
			  `todo_date` = ?,
			  `todo_status` = ?		  
		";
		$this->oDb->query($sql, $todo_user_id, $todo_action, $todo_text, $todo_date, $todo_status);
	}
	
	//
	// Arduino
	// получить задания по типу задачи и статусу        - нужно чтобы проверить есть ли уже аналогичное новое задание
	//
	public function GetTodoByAction($todo_action, $todo_status)
	{
		$sql = "
			SELECT
				*
			FROM
				`".DB_TABLE_LSARDUINO_TODO."`
			WHERE `todo_action`='".$todo_action."' AND `todo_status`='".$todo_status."'";
		
		if ($aRows=$this->oDb->select($sql)) 
		{
			return $aRows;
		}
	}
	
	//
	// Arduino
	// изменить статус задания
	//
	public function SetTodoStatus($todo_id, $todo_status)
	{
		$sql = "UPDATE `".DB_TABLE_LSARDUINO_TODO."` SET `todo_status`='".$todo_status."' WHERE todo_id = '".$todo_id."'";
		
		if ($aRows=$this->oDb->query($sql))
		{
			return 1;
		}
		return 0;
	}
	
	//
	// Arduino
	//  удаляем старые сообщения
	//
	public function DeleteOldNotes()
	{
		$sql = "
			DELETE FROM
				`".DB_TABLE_LSARDUINO."`
			WHERE
				YEARWEEK(`note_date`)<YEARWEEK(NOW())
		";
		if($this->oDb->query($sql))
			return true;
		return false;
	}
	
	//
	// Arduino
	//  удаляем старые задания
	//
	public function DeleteOldTodo()
	{
		$sql = "
			DELETE FROM
				`".DB_TABLE_LSARDUINO_TODO."`
			WHERE
				YEARWEEK(`todo_date`)<YEARWEEK(NOW())
		";
		if($this->oDb->query($sql))
			return true;
		return false;
	}
}
