#!/usr/local/bin/python
# -*- coding: utf-8 -*-
#
#----------------------------------------------------------------------------
# @Module Name: LS Arduino
# @Module URI: http://robocraft.ru
# @Description: модуль получения заданий с сайта на базе LiveStreet в виде xml-файла
# @Version: 0.01
# @Author: Vladimir (noonv)
# @Author URI: http://robocraft.ru
# @LiveStreet Version: 0.3.1
# @License: RoboCraft.ru
#----------------------------------------------------------------------------
#

import sys
import os

#
# для задержки
import time

#
# для работы с COM-портом нужна библиотека
# pySerial, кроме того, под винду понадобится еще pyWin32
#
import serial
SERIAL_PORT = 'COM18'
SERIAL_SPEED = 9600



# для работы с протоколом HTTP используем библиотеку urllib
import urllib
USER_LS_SITE_NOTE = 'http://i2.ru/include/ajax/lsarduino_add_note.php'
USER_LS_SITE_ACTION = 'http://i2.ru/include/ajax/lsarduino_set_status.php'
XML_TODO = 'http://i2.ru/lsarduino/actions'

USER_LOGIN = 'administrator'
USER_PASS = 'password'

# для работы с xml
import xml.dom.minidom

def parse_todo_xml():
	print "[i] try to read data from ", XML_TODO
	# считываем XML-ку с заданиями
	f = urllib.urlopen(XML_TODO)
	XML=f.read()
	print XML
	# теперь настала пора парсить
	dom = xml.dom.minidom.parseString(XML)
	print dom
	nodes = dom.getElementsByTagName("action")
	# получаем количество заданий
	todo_count=nodes.length
	print "[i] TODO count", todo_count
    # пробегаем по всем заданиям
	for i in range(0, todo_count):
		node=nodes[i]
		todoid = node.getElementsByTagName("id")[0].firstChild.data
		userid = node.getElementsByTagName("userid")[0].firstChild.data
		todo = node.getElementsByTagName("todo")[0].firstChild.data
		try:
		    todotext = node.getElementsByTagName("todotext")[0].firstChild.data
		except:
		    print "[!] no todotext"
		    todotext =""
		tododate = node.getElementsByTagName("tododate")[0].firstChild.data
		todostatus = node.getElementsByTagName("todostatus")[0].firstChild.data
		print "[i] ",i,": id: ", todoid," user: ", userid," action: ", todo," todotext: ", todotext," tododate: ", tododate," todostatus: ", todostatus
		# на всякий случай проверяем статус задания - нам нужны только с "Новый" - 1
		if int(todostatus)!=1:
		    print "[!] not new ", todostatus
		    continue
		# изменяфем статус задания на "Загружен" - 2
		send_data_into_ls_action(todoid, 2)
		# значения задания получили - записываем номер задания в порт
		talk_to_com(str(todo))
        # считываем ответ
		newstatus = read_data_from_com()
        # изменяфем статус задания
		send_data_into_ls_action(todoid, newstatus)
		# чуток подождём
		time.sleep(3)
	return None

#
# отправляем данные в COM-порт
#
def talk_to_com(data):
     ser = serial.Serial(SERIAL_PORT, SERIAL_SPEED)
     print "[>]Data: ",data
     ser.write(data)

#
# считываем данные из COM-порта
#
def read_data_from_com():
	ser = serial.Serial(SERIAL_PORT, SERIAL_SPEED)
	data = ser.readline().strip() # считывается строка и убираются символы “\r\n”
	#data=138
	print "[<]Data: ",data
	return data

#
# отправляем данные на сайт
#
def send_data_into_ls(data):
	print "[i] try to send data ",data
	text = "test"
	params = urllib.urlencode({"user_login":USER_LOGIN,"user_pass":USER_PASS,"note_text":text,"note_data": data})
	#print params
	#to_open= USER_LS_SITE_NOTE+"?"+params
	#print "[i] try ",to_open
	f = urllib.urlopen(USER_LS_SITE_NOTE,params)
	print f.read()
	return 0

#
# изменяем статус задания на сайте
#
def send_data_into_ls_action(todo_id, todo_status):
	print "[i] try to change status for ",todo_id
	text = "test"
	params = urllib.urlencode({"user_login":USER_LOGIN,"user_pass":USER_PASS,"todo_id":todo_id,"todo_status": todo_status})
	#print params
	#to_open= USER_LS_SITE+"?"+params
	#print "[i] try ",to_open
	f = urllib.urlopen(USER_LS_SITE_ACTION,params)
	print f.read()
	return 0
#-----------------------------------------
#
# begin here :)
#

def main():
    print "[i] Start..."

    while 1:
        # считываем данные с Arduino
        talk_to_com("0")
        data = read_data_from_com()
        if data:
            send_data_into_ls(data)
        time.sleep(10)
        # считываем задания для Arduino
        parse_todo_xml()
        time.sleep(300)

    print "[i] done."
    return None

if __name__ == "__main__":
    main()
